[llvm] 7808bf8 - NFC: Make sure function arguments have the same name in declaration and definition

Kirill Bobyrev via llvm-commits llvm-commits at lists.llvm.org
Mon Jun 15 01:45:32 PDT 2020


Author: Kirill Bobyrev
Date: 2020-06-15T10:45:08+02:00
New Revision: 7808bf843174017b5e147870f7f901a7ea7a0732

URL: https://github.com/llvm/llvm-project/commit/7808bf843174017b5e147870f7f901a7ea7a0732
DIFF: https://github.com/llvm/llvm-project/commit/7808bf843174017b5e147870f7f901a7ea7a0732.diff

LOG: NFC: Make sure function arguments have the same name in declaration and definition

This code generates Clang-Tidy warnings otherwise.

Added: 
    

Modified: 
    llvm/include/llvm/Transforms/Scalar/MemCpyOptimizer.h
    mlir/include/mlir/Dialect/SPIRV/SPIRVTypes.h

Removed: 
    


################################################################################
diff  --git a/llvm/include/llvm/Transforms/Scalar/MemCpyOptimizer.h b/llvm/include/llvm/Transforms/Scalar/MemCpyOptimizer.h
index 1570c3a08d0b..8fc6c23e6944 100644
--- a/llvm/include/llvm/Transforms/Scalar/MemCpyOptimizer.h
+++ b/llvm/include/llvm/Transforms/Scalar/MemCpyOptimizer.h
@@ -63,8 +63,8 @@ class MemCpyOptPass : public PassInfoMixin<MemCpyOptPass> {
   bool performCallSlotOptzn(Instruction *cpy, Value *cpyDst, Value *cpySrc,
                             uint64_t cpyLen, Align cpyAlign, CallInst *C);
   bool processMemCpyMemCpyDependence(MemCpyInst *M, MemCpyInst *MDep);
-  bool processMemSetMemCpyDependence(MemCpyInst *M, MemSetInst *MDep);
-  bool performMemCpyToMemSetOptzn(MemCpyInst *M, MemSetInst *MDep);
+  bool processMemSetMemCpyDependence(MemCpyInst *MemCpy, MemSetInst *MemSet);
+  bool performMemCpyToMemSetOptzn(MemCpyInst *MemCpy, MemSetInst *MemSet);
   bool processByValArgument(CallBase &CB, unsigned ArgNo);
   Instruction *tryMergingIntoMemset(Instruction *I, Value *StartPtr,
                                     Value *ByteVal);

diff  --git a/mlir/include/mlir/Dialect/SPIRV/SPIRVTypes.h b/mlir/include/mlir/Dialect/SPIRV/SPIRVTypes.h
index ffb9d4ed8cbe..95855785e31b 100644
--- a/mlir/include/mlir/Dialect/SPIRV/SPIRVTypes.h
+++ b/mlir/include/mlir/Dialect/SPIRV/SPIRVTypes.h
@@ -345,16 +345,16 @@ class StructType : public Type::TypeBase<StructType, CompositeType,
 
   uint64_t getMemberOffset(unsigned) const;
 
-  // Returns in `allMemberDecorations` the spirv::Decorations (apart from
+  // Returns in `memberDecorations` the spirv::Decorations (apart from
   // Offset) associated with all members of the StructType.
   void getMemberDecorations(SmallVectorImpl<StructType::MemberDecorationInfo>
-                                &allMemberDecorations) const;
+                                &memberDecorations) const;
 
   // Returns in `memberDecorations` all the spirv::Decorations (apart from
   // Offset) associated with the `i`-th member of the StructType.
   void getMemberDecorations(unsigned i,
                             SmallVectorImpl<StructType::MemberDecorationInfo>
-                                &memberDecorations) const;
+                                &decorationsInfo) const;
 
   void getExtensions(SPIRVType::ExtensionArrayRefVector &extensions,
                      Optional<spirv::StorageClass> storage = llvm::None);
@@ -345,16 +345,16 @@ class StructType : public Type::TypeBase<StructType, CompositeType,
 
-  // Returns in `memberDecorations` all the spirv::Decorations (apart from
+  // Returns in `decorationsInfo` all the spirv::Decorations (apart from
   // Offset) associated with the `i`-th member of the StructType.
   void getMemberDecorations(unsigned i,


        


More information about the llvm-commits mailing list